<?php

namespace Drupal\commerce_fraud\EventSubscriber;

use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Drupal\commerce_fraud\Event\FraudEvent;
use Drupal\Core\Database\Connection;

/**
 * Modifies the fraud score of orders.
 */
class FraudScoreUpdatedSubscriber implements EventSubscriberInterface {

  /**
   * The database connection.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $connection;

  /**
   * Constructs a new FraudScoreSubscriber object.
   *
   * @param \Drupal\Core\Database\Connection $connection
   *   The database connection to be used.
   */
  public function __construct(Connection $connection) {
    $this->connection = $connection;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('database')
    );
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [
      'commerce_fraud.fraud_score_insert' => ['addFraudScore'],
      'commerce_fraud.fraud_score_update' => ['changeFraudScore'],
    ];
  }

  /**
   * Inserts the fraud score.
   *
   * @param \Drupal\commerce_fraud\Event\FraudEvent $event
   *   FraudEvent class object.
   */
  public function addFraudScore(FraudEvent $event) {

    $fields = [
      'fraud_score' => $event->getScore(),
      'order_id' => $event->getOrderId(),
      'note' => $event->getNote(),
    ];

    $this->connection->insert('commerce_fraud_fraud_score')
      ->fields($fields)
      ->execute();
  }

  /**
   * Updates the fraud score.
   *
   * @param \Drupal\commerce_fraud\Event\FraudEvent $event
   *   FraudEvent object.
   */
  public function changeFraudScore(FraudEvent $event) {

    $fields = [
      'fraud_score' => $event->getScore(),
      'order_id' => $event->getOrderId(),
      'note' => $event->getNote(),
    ];
    $this->connection->update('commerce_fraud_fraud_score')
      ->fields($fields)
      ->condition('order_id', $event->getOrderId())
      ->execute();
  }

}
